@@ -71,7 +71,7 @@ NetworkStatus::NetworkStatus(QObject* parent)
     : QObject(parent)
 {
     connect(NetworkManager::notifier(), &NetworkManager::Notifier::statusChanged, this, &NetworkStatus::statusChanged);
-    connect(NetworkManager::notifier(), &NetworkManager::Notifier::activeConnectionsChanged, this, static_cast<void (NetworkStatus::*)(void)>(&NetworkStatus::activeConnectionsChanged));
+    connect(NetworkManager::notifier(), &NetworkManager::Notifier::activeConnectionsChanged, this, QOverload<>::of(&NetworkStatus::activeConnectionsChanged));
 
     activeConnectionsChanged();
     statusChanged(NetworkManager::status());
@@ -203,10 +203,11 @@ void NetworkStatus::changeActiveConnections()
                 }
 
                 NetworkManager::Connection::Ptr connection = active->connection();
+                const QString connectionName = connection->name().replace('&', "&amp;").replace('<', "&lt;").replace('>', "&gt;");
                 if (connecting) {
-                    status = i18n("Connecting to %1", connection->name());
+                    status = i18n("Connecting to %1", connectionName);
                 } else if (connected) {
-                    status = i18n("Connected to %1", connection->name());
+                    status = i18n("Connected to %1", connectionName);
                 }
 
                 if (!activeConnections.isEmpty()) {
